Component({
  /**
   * 组件的属性列表
   */
  options: {
    // addGlobalClass: true
    // styleIsolation: 'isolated'
  },

  /**
   * 扩展外部class
   */
  externalClasses: ['icon-class-activated', 'icon-class-inactivated', "message-text-class"],

  /**
   * 组件的属性列表
   */
  properties: {
    /**
     * 图标是否为激活状态
    */
    activated: { type: Boolean },
    /**
     * 图片内容
     */
    srcActivated: { type: String },
    srcInactivated: { type: String },
    /** 
     * 图标
     */
    iconType: { type: String }, // 为空 => 不显示图标形状
    iconSize: { type: String }, // iconType 不为空 => 自动设置默认值
    iconColor: { type: String },  // 为空 => 使用内置默认颜色
    iconFontAutoSize: { type: String, value: "true" }, // 如果需要外部class控制font-size, 则设置为false
    iconBackgroundColor: { type: String, value: "transparent" },
    /** 
     * 消息
     */
    message: { type: null },
    messageSize: { type: String },  // 自动设置默认值
    messageBackgroundColor: { type: String, value: 'yellow'},
    messageHOffset: { type: String, value: "0rpx" },
    messageVOffset: { type: String, value: "0rpx"},
    messageFontAutoSize: { type: String, value: "true" } // 如果需要外部class控制font-size, 则设置为false
  },

  /**
   * 组件的初始数据
   */
  data: {
    iconFontSize: '',  // 关联 properties.iconFontAutoSize, iconType 不为空 => 自动设置默认值
    messageFontSize: ''  // 关联 properties.messageFontAutoSize, 自动设置默认值
  },

  /**
 * 组件的方法列表
 * 
 * @事件 bind:switch switch事件
 */
  methods: {
    /** 激活状态转换时处理 */
    onSwitch: function () {
      new Promise((resolve, reject) => {
        // 激活自定义事件
        this.triggerEvent(
          'switch', 
          {
            // properties
            activated: this.properties.activated,
            message: this.properties.message,
            // promise
            promise: {resolve: resolve, reject: reject }
          }
        );
      })
      .then((message) => {
        // 更新返回的数据
        this.setData({
          activated: !this.properties.activated,
          message: message
        });
      });
    }
  },

  /**
   * 组件的生命周期
   */
  lifetimes: {
    attached: function () {

    },
    ready: function () {
      this.createSelectorQuery()
        .select('.container')
        .fields(
          { size: true },
          (res) => {
            let v_size = Math.min(res.width, res.height)
            let v_messageSize = this.properties.messageSize;
            /* 设置默认 messageSize 属性 */
            if ("" == v_messageSize) {
              v_messageSize = v_size * 0.6 + "px";
              this.setData({
                // 设置消息大小为组件大小的60%
                messageSize: v_messageSize
              });
            }
            /* 设置默认 messageFont 属性 */
            if ("true" == this.properties.messageFontAutoSize) {
              this.setData({
                // 设置消息字体大小为消息大小的70%
                messageFontSize: "calc(" + v_messageSize + " * 0.7)"
              });
            }
            /* 设置默认 icon 相关 */
            if ("" == this.properties.iconSize && "" != this.properties.iconType) {
              this.setData({
                iconSize: v_size
              });
            }
            if ("true" ==  this.properties.iconFontAutoSize && "" == this.properties.iconType){
              this.setData({
                iconFontSize: v_size + "px"
              });
            }
          }
        )
        .exec()
    }
  }

})
